RpcLoadBalancer.LoadBalancer.AlgorithmCache (rpc_load_balancer v0.1.0)

Copy Markdown View Source

Summary

Functions

Returns a list of all ETS tables at the node.

Deletes all objects in the ETS table.

Deletes the exact object from the ETS table.

Deletes the entire ETS table.

Reads a file produced by tab2file/1,2 and creates the corresponding table.

Reads a file produced by tab2file/1,2 and creates the corresponding table with options.

Returns the first key in the table.

Returns the first key and object(s) in the table. (OTP 26+)

Folds over all objects in the table from first to last.

Folds over all objects in the table from last to first.

Convert a DETS table to an ETS table.

Makes process pid the new owner of the table.

Get information about the ETS table.

Get specific information about the ETS table.

Replaces the existing objects of the table with objects created by calling the input function.

Same as insert/2 except returns false if any object with the same key already exists.

Insert raw data into the ETS table using the underlying :ets.insert/2 function.

Checks if a term represents a valid compiled match specification.

Returns the last key in the table (for ordered_set, otherwise same as first).

Returns the last key and object(s) in the table. (OTP 26+)

Returns a list of all objects with the given key.

Returns the Pos:th element of the object with the given key.

Returns the Pos:th element of the object with the given key, or default if not found. (OTP 26+)

Continues a match started with match/2.

Deletes all objects that match the pattern from the table.

Match objects in the ETS table that match the given pattern.

Match objects in the ETS table that match the given pattern with limit.

Matches the objects in the table against the pattern.

Matches the objects in the table against the pattern with a limit.

Transforms a match specification into an internal representation.

Executes the matching specified in a compiled match specification on a list of terms.

Check if a key is a member of the ETS table.

Returns the next key following the given key.

Returns the next key and object(s) following the given key. (OTP 26+)

Returns the previous key preceding the given key (for ordered_set).

Returns the previous key and object(s) preceding the given key. (OTP 26+)

Renames the table to the new name.

Restores an opaque continuation that has passed through external term format.

Fixes the table for safe traversal.

Select objects from the ETS table using a match specification.

Select objects from the ETS table using a match specification with limit.

Counts the objects matching the match specification.

Delete objects from the ETS table using a match specification.

Replaces objects matching the match specification with the match specification result.

Like select/1 but returns the list in reverse order for ordered_set.

Like select/2 but traverses in reverse order for ordered_set.

Sets table options (only heir is allowed after creation).

Returns the list of objects associated with slot I.

Dumps the table to a file.

Dumps the table to a file with options.

Returns a list of all objects in the table.

Returns information about the table dumped to file.

Returns a QLC query handle for the table.

Returns a QLC query handle for the table with options.

Returns and removes all objects with the given key.

Tests a match specification against a tuple.

Convert an ETS table to a DETS table.

Update a counter in the ETS table.

Update a counter in the ETS table with a default value.

Updates specific elements of an object.

Updates specific elements of an object with a default. (OTP 26+)

Returns the tid of this named table.

Functions

adapter_options()

all()

Returns a list of all ETS tables at the node.

cache_adapter()

cache_name()

child_spec(_)

delete(key)

delete_all_objects()

Deletes all objects in the ETS table.

delete_object(object)

Deletes the exact object from the ETS table.

delete_table()

Deletes the entire ETS table.

file2tab(filename)

Reads a file produced by tab2file/1,2 and creates the corresponding table.

file2tab(filename, options)

Reads a file produced by tab2file/1,2 and creates the corresponding table with options.

first()

Returns the first key in the table.

first_lookup()

Returns the first key and object(s) in the table. (OTP 26+)

foldl(function, acc)

Folds over all objects in the table from first to last.

foldr(function, acc)

Folds over all objects in the table from last to first.

from_dets(dets_table)

Convert a DETS table to an ETS table.

get(key)

get_or_create(key, fnc)

give_away(pid, gift_data)

Makes process pid the new owner of the table.

info()

Get information about the ETS table.

info(item)

Get specific information about the ETS table.

init_table(init_fun)

Replaces the existing objects of the table with objects created by calling the input function.

insert_new(data)

Same as insert/2 except returns false if any object with the same key already exists.

insert_raw(data)

Insert raw data into the ETS table using the underlying :ets.insert/2 function.

is_compiled_ms(term)

Checks if a term represents a valid compiled match specification.

last()

Returns the last key in the table (for ordered_set, otherwise same as first).

last_lookup()

Returns the last key and object(s) in the table. (OTP 26+)

lookup(key)

Returns a list of all objects with the given key.

lookup_element(key, pos)

Returns the Pos:th element of the object with the given key.

lookup_element(key, pos, default)

Returns the Pos:th element of the object with the given key, or default if not found. (OTP 26+)

match(continuation)

Continues a match started with match/2.

match_delete(pattern)

Deletes all objects that match the pattern from the table.

match_object(continuation)

Match objects in the ETS table that match the given pattern.

match_object(pattern, limit)

Match objects in the ETS table that match the given pattern with limit.

match_pattern(pattern)

Matches the objects in the table against the pattern.

match_pattern(pattern, limit)

Matches the objects in the table against the pattern with a limit.

match_spec_compile(match_spec)

Transforms a match specification into an internal representation.

match_spec_run(list, compiled_match_spec)

Executes the matching specified in a compiled match specification on a list of terms.

member(key)

Check if a key is a member of the ETS table.

next(key)

Returns the next key following the given key.

next_lookup(key)

Returns the next key and object(s) following the given key. (OTP 26+)

prev(key)

Returns the previous key preceding the given key (for ordered_set).

prev_lookup(key)

Returns the previous key and object(s) preceding the given key. (OTP 26+)

put(key, ttl \\ nil, value)

rename(name)

Renames the table to the new name.

repair_continuation(continuation, match_spec)

Restores an opaque continuation that has passed through external term format.

safe_fixtable(fix)

Fixes the table for safe traversal.

select(continuation)

Select objects from the ETS table using a match specification.

select(match_spec, limit)

Select objects from the ETS table using a match specification with limit.

select_count(match_spec)

Counts the objects matching the match specification.

select_delete(match_spec)

Delete objects from the ETS table using a match specification.

select_replace(match_spec)

Replaces objects matching the match specification with the match specification result.

select_reverse(continuation)

Like select/1 but returns the list in reverse order for ordered_set.

select_reverse(match_spec, limit)

Like select/2 but traverses in reverse order for ordered_set.

setopts(opts)

Sets table options (only heir is allowed after creation).

slot(i)

Returns the list of objects associated with slot I.

tab2file(filename)

Dumps the table to a file.

tab2file(filename, options)

Dumps the table to a file with options.

tab2list()

Returns a list of all objects in the table.

tabfile_info(filename)

Returns information about the table dumped to file.

table()

Returns a QLC query handle for the table.

table(options)

Returns a QLC query handle for the table with options.

take(key)

Returns and removes all objects with the given key.

test_ms(tuple, match_spec)

Tests a match specification against a tuple.

to_dets(dets_table)

Convert an ETS table to a DETS table.

update_counter(key, update_op)

Update a counter in the ETS table.

update_counter(key, update_op, default)

Update a counter in the ETS table with a default value.

update_element(key, element_spec)

Updates specific elements of an object.

update_element(key, element_spec, default)

Updates specific elements of an object with a default. (OTP 26+)

whereis()

Returns the tid of this named table.