Shared atomic counters for slot-based round-robin and per-node connection tracking across all load balancers.
Summary
Functions
Atomically decrements the counter for the given key by step (default 1).
Atomically increments the counter for the given key by step (default 1).
Functions
Atomically decrements the counter for the given key by step (default 1).
@spec get_and_increment(non_neg_integer()) :: non_neg_integer()
@spec get_node_count(atom(), node()) :: non_neg_integer()
Atomically increments the counter for the given key by step (default 1).
@spec register(atom(), pos_integer()) :: non_neg_integer()
@spec register_node(atom(), node()) :: non_neg_integer()
@spec reset_counter(non_neg_integer()) :: :ok