RpcLoadBalancer.LoadBalancer.DrainerCache (rpc_load_balancer v0.2.1)

Copy Markdown View Source

Shared atomic counter for tracking in-flight calls per load balancer.

Summary

Functions

Atomically decrements the counter for the given key by step (default 1).

Atomically increments the counter for the given key by step (default 1).

Functions

adapter_options()

cache_adapter()

cache_name()

child_spec(_)

count(index)

@spec count(non_neg_integer()) :: non_neg_integer()

decrement(key, step \\ 1)

Atomically decrements the counter for the given key by step (default 1).

delete(key)

get(key)

get_or_create(key, fnc)

increment(key, step \\ 1)

Atomically increments the counter for the given key by step (default 1).

put(key, ttl \\ nil, value)

register(load_balancer_name)

@spec register(atom()) :: non_neg_integer()