Shared atomic counter for tracking in-flight calls per load balancer.
Summary
Functions
Atomically decrements the counter for the given key by step (default 1).
Atomically increments the counter for the given key by step (default 1).
Functions
@spec count(non_neg_integer()) :: non_neg_integer()
Atomically decrements the counter for the given key by step (default 1).
Atomically increments the counter for the given key by step (default 1).
@spec register(atom()) :: non_neg_integer()